.. _whats_new:

.. currentmodule:: horizont

============
 What's New
============

v0.0.4 (8. September, 2014)
===========================

- Significant performance improvements.
- Preliminary support for installing on OS X without GSL under Python 3.
